# Qbus MQTT API
Python MQTT API for Qbus Home Automation

This package is an extention for the Qbus integration in Home Assistant.

It includes all convertions from the mqtt protocol which enables Home Assistant to communicate with Qbus Controllers.

For more information, please visi https://iot.qbus.be

